Alfa.rs Factor Visualization

### Alpha Selection

Select alpha factors from library for batch backtesting

Category:
Select Alphas:
Loading alphas...

### Data Source

Table:
Date Range:
to
Filter:

## Data Source Configuration

Configure ClickHouse database connection and load real market data

### Database Connection

Not connected
Host:
Port:
Username:
Password:

### Column Mapping

Map your database column names to standard names. Select from available columns or enter custom names.

Close Column:
Open Column:
High Column:
Low Column:
Volume Column:
Symbol Column:
Date Column:

### Table Mapping

Select the database tables for each frequency (1 Day is required)

1 Day Table:
5 Min Table (optional):
1 Min Table (optional):

## GP Factor Mining

Configure genetic programming parameters to discover new factors

### Configuration

#### Seed Alpha (Optional)

Select an alpha from library to use as seed for mutation-based mining

Category:
Select Alpha:
Loading alphas...

#### Data Source

Table:
Date Range:
to
Filter:
Population Size:
Max Generations:
Terminal Set:
close open high low volume returns amount turnover
Function Set:
add sub mul div sqrt abs neg rank ts_mean ts_std ts_max ts_min delay log sign ts_rank decay_linear correlation
Target IC:

### Results

Ready to start

## Alpha Factor Library

Browse .al factor files from ~/.alfars/ (readonly) and ~/.alfars/user/ (writable)

### Alpha Factors

Loading alphas...

### Alpha Details

#### Data Source

Table:
Date Range:
to
Expression: ``
Description:
Dimension:
Tags:
Status:
IC Mean --
IC IR --

#### Backtest Results

IC Mean --
IC IR --
Total Return --
Annualized Return --
Sharpe Ratio --
Max Drawdown --
Turnover --

### Save GP Result

Name:
Expression: ``
Description:
Dimension:
Tags (comma-separated):